@@ -35,9 +35,9 @@ class DecoderSelfAttention(AttentionBase):
         attention_state: FloatTensor,
         token_index: LongTensor
     ) -> Tuple[FloatTensor, FloatTensor]:
-        keys = self.k_proj.forward(decoder_state)
-        values = self.v_proj.forward(decoder_state)
-        queries = self.q_proj.forward(decoder_state)
+        keys = self.k_proj.forward(decoder_state).to(torch.float32)
+        values = self.v_proj.forward(decoder_state).to(torch.float32)
+        queries = self.q_proj.forward(decoder_state).to(torch.float32)
         attn_mask = self.token_indices < token_index + 1
         attn_mask = attn_mask[None][[0] * decoder_state.shape[0]]
         attn_state_new = torch.cat([keys, values]).to(attention_state.dtype)
@@ -165,7 +165,7 @@ class DalleBartDecoder(nn.Module):
                 token_index
             )
         decoder_state = self.final_ln(decoder_state)
-        logits = self.lm_head(decoder_state).to(torch.float32)
+        logits = self.lm_head(decoder_state)
         a = 2 ** log2_supercondition_factor
         logits: FloatTensor = (
             logits[:image_count, -1] * (1 - a) + 
