@@ -63,8 +63,8 @@ class AttentionBase(nn.Module):
         attention_weights = torch.softmax(attention_weights, -1)
         attention_output: FloatTensor = torch.einsum(
             "bhqk,bkhc->bqhc",
-            attention_weights, 
-            values
+            attention_weights.to(torch.float32), 
+            values.to(torch.float32)
         )
         shape = attention_output.shape[:2] + (self.embed_count,)
         attention_output = attention_output.reshape(shape)
